<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="115"/>
        <source>No text recognized</source>
        <translation>Er is geen tekst aangetroffen</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>Recognize language</source>
        <translation>Taal herkennen</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Simplified Chinese</source>
        <translation>Vereenvoudigd Chinees</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>English</source>
        <translation>Engels</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Traditional Chinese</source>
        <translation>Traditioneel Chinees</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="204"/>
        <source>Copy text</source>
        <translation>Tekst kopiëren</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="210"/>
        <source>Save as TXT</source>
        <translation>Opslaan als txt-bestand</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="236"/>
        <source>Undo (Ctrl+Z)</source>
        <translation>Ongedaan maken (Ctrl+Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="247"/>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation>Opnieuw uitvoeren (Ctrl+Shift+Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="294"/>
        <location filename="../src/mainwidget.cpp" line="335"/>
        <source>Recognizing</source>
        <translation>Bezig met herkennen…</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="563"/>
        <source>Copied</source>
        <translation>Gekopieerd</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="75"/>
        <source>OCR Tool</source>
        <translation>OCR-hulpmiddel</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="24"/>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="27"/>
        <source>Select All</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="29"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="283"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>Tip: gebruik een heldere afbeelding zodat de tekst goed leesbaar is</translation>
    </message>
</context>
</TS>